/* orcad_convert.h
 *
 * This is part of the orcad_convert utility
 * Copyright (c) 2020 Dimitri Marinakis
 * see the file orcad_convert.c for copying conditions
 *
 * 18-Feb-2020 dm
 */

#include <stdlib.h>
#include <stdint.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <stdio.h>
#include <unistd.h>
#include <ctype.h>
#include <string.h>
#include <errno.h>

#define INRECSIZE 0xFFFFF
#define OUTRECSIZE 0xFFFFF

/* Orcad SDT strings are 256 characters maximum; 
 * extra space used for adding conversion data
 */
#define MAXFILELEN 512
#define MAXSTRING 512 
#define MAXCOMPONENTS 20000

/* Header data
 */
#define HEADER_RECORD_LENGTH 0x172
#define SIZE_A 0
#define SIZE_B 1
#define SIZE_C 2
#define SIZE_D 3
#define SIZE_E 4

/* Record types
 * Title block (Tag = 0) is 
 * processed right after the header
 */
#define SHEET 1
#define COMPONENT 2
#define WIRE 3
#define BUS 4
#define JUNCTION 5
#define MODULE_PORT 6
#define LABEL 7
#define ENTRY 8
#define DASHED_LINE 9
#define POWER 0x0A
#define TEXT 0x0B
#define MARKER 0x0C
#define END_OF_FILE 0x0F

/* Scale and offset
 * Offset is used for sheets with borders (default: 470 mils)
 */
#define SCALE 10
#define OFF_X 470
#define OFF_Y 470
// #define OFF_X 0
// #define OFF_Y 0

/* Module parameters (shape, function)
 */
#define NEITHER 0
#define LEFT 1
#define RIGHT 2
#define BOTH 3

#define UNSPECIFIED 0
#define OUTPUT 1
#define INPUT 2
#define BIDIRECTIONAL 3

